@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-import sys, os, pkginfo, datetime
+import os, pkginfo, datetime
 
 pkg_info = pkginfo.Develop(os.path.join(os.path.dirname(__file__),'..'))
 
@@ -10,20 +10,19 @@ extensions = [
 
 intersphinx_mapping = {
     'http://docs.python.org': None,
-    'http://packages.python.org/testfixtures/': None,
-    # XXX - errorhandler
-    # XXX - xlrd
-    # XXX - xlwt
+    'http://testfixtures.readthedocs.io/en/latest/': None,
+    'http://pythonhosted.org/errorhandler/': None,
+    'http://xlrd.readthedocs.io/en/latest/': None,
+    'http://xlwt.readthedocs.io/en/latest/': None,
     }
 
 # General
-source_suffix = '.txt'
+source_suffix = '.rst'
 master_doc = 'index'
 project = pkg_info.name
 copyright = '2008-%s Simplistix Ltd' % datetime.datetime.now().year
 version = release = pkg_info.version
 exclude_trees = ['_build']
-unused_docs = ['description']
 pygments_style = 'sphinx'
 
 # Options for HTML output
